boto v2.11.0 — boto v2.16.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.16.0 »

# boto v2.11.0

date: | 2013/08/29

This release adds Public IP address support for VPCs created by EC2. It also makes the GovCloud region available for all services. Finally, this release also fixes a number of bugs.

## Features

- Added Public IP address support within VPCs created by EC2. (commit be132d1)
- All services can now easily use GovCloud. (issue 1651, commit 542a301, commit 3c56121, commit 9167d89)
- Added `db_subnet_group` to `RDSConnection.restore_dbinstance_from_point_in_time`. (issue 1640, commit 06592b9)
- Added `monthly_backups` to EC2’s `trim_snapshots`. (issue 1688, commit a2ad606, commit 2998c11, commit e32d033)
- Added `get_all_reservations` & `get_only_instances` methods to EC2. (issue 1572, commit ffc6cc0)

## Bugfixes

- Fixed the parsing of CloudFormation’s `LastUpdatedTime`. (issue 1667, :sha:` 70f363a`)

- Fixed STS’ `assume_role_with_web_identity` to work correctly. (issue 1671, commit ed1f403, commit ca794d5, commit ed7e563, commit 859762d)

- Fixed how VPC security group filtering is done in EC2. (issue 1665, issue 1677, commit be00956, commit 5e85dd1, commit e63aae8)

- Fixed fetching more than 100 records with `ResourceRecordSet`. (issue 1647, issue 1648, issue 1680, commit b64dd4f, commit 276df7e, commit e57cab0, commit e62a58b, commit 4c81bea, commit a3c635b)

- Fixed how VPC Security Groups are referred to when working with RDS. (issue 1602, issue 1683, issue 1685, issue 1694, commit 012aa0c, commit d5c6dfa, commit 7841230, commit 0a90627, commit ed4fd8c, commit 61d394b, commit ebe84c9, commit a6b0f7e)

- Google Storage `Key` now uses transcoding-invariant headers where possible. (commit d36eac3)

- Doing non-multipart uploads when using `s3put` no longer requires having the `ListBucket` permission. (issue 1642, issue 1693, commit f35e914)

- Fixed the serialization of `attributes` in a variety of SNS methods. (issue 1686, commit 4afb3dd, commit a58af54)

- Fixed SNS to be better behaved when constructing an mobile push notification. (issue 1692, commit 62fdf34)

- Moved SWF to SigV4. (commit ef7d255)

- Several documentation improvements/fixes:

  > - Updated the DynamoDB v2 docs to correct how the connection is built. (issue 1662, commit 047962d)
  > - Fixed a typo in the DynamoDB v2 docstring for `Table.create`. (commit be00956)
  > - Fixed a typo in the DynamoDB v2 docstring for `Table` for custom connections. (issue 1681, commit 6a53020)
  > - Fixed incorrect parameter names for `DBParameterGroup` in RDS. (issue 1682, commit 0d46aed)
  > - Fixed a typo in the SQS tutorial. (issue 1684, commit 38b7889)

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.16.0 »